@@ -41,8 +41,6 @@
 
 #define BLUEZQT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(BLUEZQT_NO_DEPRECATED) && !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BLUEZQT_NO_DEPRECATED
-#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
 #  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef BLUEZQT_DEPRECATED
-#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
